#importation des librairies
import streamlit as st
from pycaret.classification import load_model, predict_model
import pandas

#insérer un titre
st.title("Streamlit - Déploiement modèle")

#mise en cache du chargement du modèle
#pickle (.pkl)
@st.cache_resource
def chargement_modele():
    return load_model("modele_ricco")

#chargement effectif
modele = chargement_modele()

#organisation en deux colonnes (1/4, 3/4)
#de l'espace d'affichage
col1,col2 = st.columns([1,3])

#text_input alignés sur la première colonne
diastolic = col1.text_input("Diastolic : ", "72",max_chars = 3)
bodymass = col1.text_input("Bodymass : ", "33",max_chars = 3)
age = col1.text_input("Age : ", "50", max_chars = 3)
plasma = col1.text_input("Plasma : ", "148", max_chars = 3)

#fonction pour transtypage avec contrôle
#valeur pas valide = NaN pour valeur manquante
#parce que PyCaret gère ainsi
def try_parse(str_value):
    try:
        value = float(str_value)
    except Exception:
        value = float('NaN')
    #renvoyer le résultat
    return value

#conversion en dictionnaire des données saisies par l'utilisateur
la_data = {'diastolic': try_parse(diastolic), 'bodymass':try_parse(bodymass), 
        'age': try_parse(age), 'plasma': try_parse(plasma)}

#calcul de la classe d'appartenance
#appel de la fonction de prédiction basée sur le modèle chargé
try:
    la_prediction = predict_model(modele,data = pandas.DataFrame([la_data]))
except Exception:
    la_prediction = "inconnu"

#bouton pour faire calculer (pas indispensable en fait)
st.button("Calculer")

#affichage de la classe et du score d'appartenance
st.write("Classe d'appartenance =", la_prediction[['prediction_label','prediction_score']])
